package com.ruoyi.abuwx.service;

import com.ruoyi.abuwx.domain.VideoContent;
import com.ruoyi.abuwx.vo.VideoContentVo;

import java.util.List;

/**
 * 视频信息Service接口
 * 
 * @author lujie
 * @date 2025-01-13
 */
public interface IVideoContentService 
{
    /**
     * 查询视频信息
     * 
     * @param id 视频信息主键
     * @return 视频信息
     */
    public VideoContent selectVideoContentById(Long id);

    /**
     * 查询视频信息列表
     * 
     * @param videoContent 视频信息
     * @return 视频信息集合
     */
    public List<VideoContent> selectVideoContentList(VideoContent videoContent);

    /**
     * 新增视频信息
     * 
     * @param videoContent 视频信息
     * @return 结果
     */
    public int insertVideoContent(VideoContent videoContent);

    /**
     * 修改视频信息
     * 
     * @param videoContent 视频信息
     * @return 结果
     */
    public int updateVideoContent(VideoContent videoContent);

    /**
     * 批量删除视频信息
     * 
     * @param ids 需要删除的视频信息主键集合
     * @return 结果
     */
    public int deleteVideoContentByIds(Long[] ids);

    /**
     * 删除视频信息信息
     * 
     * @param id 视频信息主键
     * @return 结果
     */
    public int deleteVideoContentById(Long id);

    List<VideoContentVo> selectVideoContentVoList(VideoContent videoContent);
}
